@@ -1109,7 +1109,7 @@ typedef enum {
 	/**
 	 * FWUPD_INSTALL_FLAG_NO_SEARCH:
 	 *
-	 * This is now unused; see #FuFirmwareParseFlags.
+	 * This is now only for internal use.
 	 *
 	 * Since: 1.5.0
 	 */
@@ -1122,6 +1122,14 @@ typedef enum {
 	 * Since: 1.9.21
 	 */
 	FWUPD_INSTALL_FLAG_IGNORE_REQUIREMENTS = 1 << 9,
+	/**
+	 * FWUPD_INSTALL_FLAG_ONLY_EMULATED:
+	 *
+	 * Only install to emulated devices.
+	 *
+	 * Since: 2.0.10
+	 */
+	FWUPD_INSTALL_FLAG_ONLY_EMULATED = 1 << 10,
 	/*< private >*/
 	FWUPD_INSTALL_FLAG_UNKNOWN = G_MAXUINT64,
 } FwupdInstallFlags;
